@@ -3,7 +3,7 @@ mod native {
     use crate::{input_edit::InputEdit, language::Language, point::Point, range::Range, tree_cursor::TreeCursor};
     use std::{borrow::Cow, convert::TryFrom};
 
-    #[derive(Clone, Eq, Hash, PartialEq)]
+    #[derive(Clone, Copy, Eq, Hash, PartialEq)]
     pub struct Node<'tree> {
         pub(crate) inner: tree_sitter::Node<'tree>,
     }
@@ -219,6 +219,7 @@ mod native {
         }
 
         #[inline]
+        #[allow(clippy::wrong_self_convention)]
         pub fn to_sexp(&self) -> Cow<str> {
             self.inner.to_sexp().into()
         }
@@ -251,6 +252,31 @@ mod native {
             Node { inner }
         }
     }
+
+    impl<'a> Ord for Node<'a> {
+        fn cmp(&self, that: &Self) -> std::cmp::Ordering {
+            let this = self.id();
+            let that = that.id();
+            this.cmp(&that)
+        }
+    }
+
+    impl<'a> PartialOrd for Node<'a> {
+        fn partial_cmp(&self, that: &Node<'a>) -> Option<std::cmp::Ordering> {
+            let this = self.id();
+            let that = that.id();
+            this.partial_cmp(&that)
+        }
+    }
+
+    impl<'a> std::panic::RefUnwindSafe for Node<'a> {
+    }
+
+    impl<'a> Unpin for Node<'a> {
+    }
+
+    impl<'a> std::panic::UnwindSafe for Node<'a> {
+    }
 }
 
 #[cfg(not(target_arch = "wasm32"))]
@@ -504,6 +530,7 @@ mod wasm {
 
         // FIXME: check that this is correct
         #[inline]
+        #[allow(clippy::wrong_self_convention)]
         pub fn to_sexp(&self) -> Cow<str> {
             From::<String>::from(self.inner.to_string().into())
         }
@@ -570,6 +597,31 @@ mod wasm {
             self.inner.len()
         }
     }
+
+    impl<'a> Ord for Node<'a> {
+        fn cmp(&self, that: &Self) -> std::cmp::Ordering {
+            let this = self.id();
+            let that = that.id();
+            this.cmp(&that)
+        }
+    }
+
+    impl<'a> PartialOrd for Node<'a> {
+        fn partial_cmp(&self, that: &Node<'a>) -> Option<std::cmp::Ordering> {
+            let this = self.id();
+            let that = that.id();
+            this.partial_cmp(&that)
+        }
+    }
+
+    impl<'a> std::panic::RefUnwindSafe for Node<'a> {
+    }
+
+    impl<'a> Unpin for Node<'a> {
+    }
+
+    impl<'a> std::panic::UnwindSafe for Node<'a> {
+    }
 }
 
 #[cfg(target_arch = "wasm32")]
